

print("What is your name?")
name = input()
if name == "Sam":
	print("What the hell, %s? Make it yourself." % name)
elif name == "Fred":
	print("Make it yourself, Fred.")
else: 
	print("Thank you, %s. I'll have a BLT." % name)